@@ -7,10 +7,10 @@ try:
 except:
     import urllib.parse as urlparse  # py3
 
+from django.utils.functional import cached_property
 
 from .utils import import_by_path
-from .settings import EMBED_VIDEO_BACKENDS, EMBED_VIDEO_CACHE, \
-                      EMBED_VIDEO_CACHE_TIMEOUT
+from .settings import EMBED_VIDEO_BACKENDS, EMBED_VIDEO_CACHE
 
 cache = None
 if EMBED_VIDEO_CACHE:
@@ -110,7 +110,14 @@ class VideoBackend(object):
         self.backend = self.__class__.__name__
         self.code = self.get_code()
         self.url = self.get_url()
-        self.thumbnail = self.get_thumbnail_url()
+
+    @cached_property
+    def thumbnail(self):
+        return self.get_thumbnail_url()
+
+    @cached_property
+    def info(self):
+        return self.get_info()
 
     @classmethod
     def is_valid(klass, url):
@@ -141,6 +148,18 @@ class VideoBackend(object):
         """
         return self.pattern_thumbnail_url % self.code
 
+    def get_embed_code(self, width, height):
+        """
+        Returns embed code.
+        """
+        return '<iframe width="%(width)d" height="%(height)d" ' \
+                'src="%(url)s" frameborder="0" allowfullscreen>' \
+                '</iframe>' % {
+                    'url': self.url,
+                    'width': width,
+                    'height': height,
+                }
+
 
 class YoutubeBackend(VideoBackend):
     """
@@ -192,12 +211,9 @@ class VimeoBackend(VideoBackend):
     pattern_url = 'http://player.vimeo.com/video/%s'
     pattern_info = 'http://vimeo.com/api/v2/video/%s.json'
 
-    info = None
-
     def init(self, url):
         self._url = url
         self.code = self.get_code()
-        self.info = self.get_info()
 
         super(VimeoBackend, self).init(url)
 
@@ -209,7 +225,7 @@ class VimeoBackend(VideoBackend):
             raise VideoDoesntExistException()
 
     def get_thumbnail_url(self):
-        return self.info['thumbnail_large']
+        return self.info.get('thumbnail_large')
 
 
 class SoundCloudBackend(VideoBackend):
@@ -222,27 +238,33 @@ class SoundCloudBackend(VideoBackend):
     re_code = re.compile(r'src=".*%2F(?P<code>\d+)&show_artwork.*"', re.I)
     re_url = re.compile(r'src="(?P<url>.*?)"', re.I)
 
-    def init(self, url):
+    @cached_property
+    def width(self):
+        return self.info.get('width')
+
+    @cached_property
+    def height(self):
+        return self.info.get('height')
+
+    def get_info(self):
         params = {
             'format': 'json',
-            'url': url,
+            'url': self._url,
         }
-
         r = requests.get(self.base_url, data=params)
-        self.response = json.loads(r.text)
-
-        self.width = self.response.get('width')
-        self.height = self.response.get('height')
-
-        super(SoundCloudBackend, self).init(url)
+        return json.loads(r.text)
 
     def get_thumbnail_url(self):
-        return self.response.get('thumbnail_url')
+        return self.info.get('thumbnail_url')
 
     def get_url(self):
-        match = self.re_url.search(self.response.get('html'))
+        match = self.re_url.search(self.info.get('html'))
         return match.group('url')
 
     def get_code(self):
-        match = self.re_code.search(self.response.get('html'))
+        match = self.re_code.search(self.info.get('html'))
         return match.group('code')
+
+    def get_embed_code(self, width, height):
+        return super(SoundCloudBackend, self). \
+                get_embed_code(width=width, height=self.height)
